@@ -4,7 +4,7 @@ use warnings;
 package Dist::Zilla::PluginBundle::DAGOLDEN;
 # ABSTRACT: Dist::Zilla configuration the way DAGOLDEN does it
 
-our $VERSION = '0.077';
+our $VERSION = '0.078';
 
 # Dependencies
 use Moose 0.99;
@@ -78,6 +78,13 @@ has no_git => (
     default => sub { $_[0]->payload->{no_git} },
 );
 
+has no_copy_files => (
+    is      => 'ro',
+    isa     => 'Bool',
+    lazy    => 1,
+    default => sub { $_[0]->payload->{no_copy_files} },
+);
+
 has no_critic => (
     is      => 'ro',
     isa     => 'Bool',
@@ -369,10 +376,16 @@ sub configure {
 
         # copy files from build back to root for inclusion in VCS;
         # for auto_version we want cpanfile.  For embedded version we want Makefile.PL
-        [
-            'CopyFilesFromBuild::Filtered' =>
-              { copy => $self->auto_version ? 'cpanfile' : 'Makefile.PL' }
-        ],
+        (
+            $self->no_copy_files
+            ? ()
+            : (
+                [
+                    'CopyFilesFromBuild::Filtered' =>
+                      { copy => $self->auto_version ? 'cpanfile' : 'Makefile.PL' }
+                ]
+            )
+        ),
 
         # manifest -- must come after all generated files
         'Manifest', # core
@@ -470,7 +483,7 @@ Dist::Zilla::PluginBundle::DAGOLDEN - Dist::Zilla configuration the way DAGOLDEN
 
 =head1 VERSION
 
-version 0.077
+version 0.078
 
 =head1 SYNOPSIS
 
@@ -568,7 +581,7 @@ following dist.ini:
   ; manifest (after all generated files)
   [Manifest]          ; create MANIFEST
 
-  ; copy cpanfile back to repo dis
+  ; copy Makefile.PL back to repo dis
   [CopyFilesFromBuild::Filtered]
   copy = Makefile.PL
 
@@ -685,6 +698,10 @@ C<no_git> — bypass all git-dependent plugins
 
 =item *
 
+C<no_copy_files> — skip copying Makefile.PL or cpanfile
+
+=item *
+
 C<no_critic> — omit C<Test::Perl::Critic> tests
 
 =item *
